;; Allegro CL for Windows Preferences

;; -----------------------------------------------------------
;; The following three forms need to appear first in this file

:has-version-check

(in-package :common-lisp-user) 

(unless 
   (string-equal (lisp-implementation-version) 
      "3.0.1 Release: 18-Jun-96 16:12")
   (unless (y-or-n-p (format nil "~
The preferences file (~a) appears to have been saved in a different ~
version of Allegro CL.  Continuing to load this file may cause errors.

Select Yes to continue loading.  Select No to proceed without loading."
            *load-pathname*))
      (throw 'acl::stop-loading nil)))

;; -----------------------------------------------------------
;; Items from the Preferences Dialog

;; Compiler Preferences

(setq *save-doc-strings* t)
(setq *save-lambda-lists* t)
(setq *fasl-save-doc-strings* nil)
(setq *fasl-save-lambda-lists* nil)
(setq *methods-named* t)
(setq *speed-level* 3)
(setq *safety-level* 2)
(setq *space-level* 0)
(setq *warn-on-protected-generic-function-redefinition* t)
(setq *warn-on-protected-function-redefinition* t)
(setq *warn-on-protected-class-redefinition* t)

;; Reader Preferences

(setq *case-sensitive-intern* t)
(setq *read-tolerant* nil)
(setq *read-source* nil)
(setq *read-dos-mode* nil)
(setq *read-base* 10)
(setq *read-case* :upcase)

;; Printer Preferences

(setq *print-escape* t)
(setq *print-pretty* nil)
(setq *print-circle* nil)
(setq *print-gensym* t)
(setq *print-array* t)
(setq printer:*print-line-wraps* nil)
(setq printer:*print-structure* t)
(setq *print-radix* nil)
(setq *print-base* 10)
(setq *print-case* :downcase)
(setq *top-print-level* 6)
(setq *top-print-length* 12)
(setq *print-level* nil)
(setq *print-length* nil)
(setq *trace-print-level* 6)
(setq *trace-print-length* 12)

;; Inspector Preferences

(setq insp:*inspect-all-slots* t)
(setq insp:*sort-inspected-slots* t)
(setq insp:*inspect-bit-vector-as-sequence* t)
(setq insp:*inspect-string-as-sequence* t)
(setq insp:*inspect-structure-as-sequence* nil)
(setq insp:*inspect-bitmap-as-array* nil)
(setq insp:*sequence-structure-slots-settable* nil)
(setq insp:*inspect-length* 300)
(setq insp:*inspect-list* :sequence)
(setq dbg:*backtrace-list-font* 
   #.(make-font :modern :courier\ new 22 '(:bold)))
(setq insp:*inspector-font* 
   #.(make-font :modern :courier\ new 22 '(:bold)))

;; Text-Editor Preferences

(setq te:*analyse-definitions-on-opening* nil)
(setq top:*cross-reference-forms* t)
(setq printer:*justify-comments* t)
(setq *warn-on-redefinition* t)
(setq te:*flash-how-often* t)
(setq te:*editor-mode* :host)
(setq te:*pretty-printer* :reindent)
(setq printer:*comment-indent* 55)
(setq te:*editor-font* 
   #.(make-font :modern :courier\ new 20 '(:bold)))

;; Toploop Preferences

(setq top:*top-query-exit* t)
(setq *load-verbose* nil)
(setq *break-on-warnings* nil)
(setq top:*top-prompt* "~%~*~V@{>~} ")
(setq *help-font* #.(make-font nil :bazooka 31 nil))
(setq top:*top-history-limit* 40)
(setq *lisp-clipboard-limit* 20)
(setq top:*lisp-status-bar-number-of-lines* 2)
(setq top:*lisp-status-bar-font* 
   #.(make-font :swiss :arial 19 '(:bold)))
(setq top:*top-font* #.(make-font :modern :courier\ new 22 '(:bold)))

;; Window-Sizes Preferences

(setq *default-window-width-factor* 0.8)
(setq *default-window-height-factor* 0.5)
(setq *default-window-width* nil)
(setq *default-window-height* nil)
(setq insp:*inspector-window-width-factor* 0.6)
(setq insp:*inspector-window-height-factor* 0.4)
(setq insp:*inspector-window-width* nil)
(setq insp:*inspector-window-height* nil)
(setq dbg:*stack-browser-window-left* 50)
(setq dbg:*stack-browser-window-top* nil)
(setq dbg:*stack-browser-window-width* 352)
(setq dbg:*stack-browser-window-height* 286)

;; Tab-1 Preferences

(setq *short-site-name* "MazeLand")
(setq *long-site-name* "Maze is Life!")
(setq *user-name* "Eli Barzilay")
(setq *machine-instance* "PC")

;; -----------------------------------------------------------
;; Items NOT from the Preferences Dialog

;; Initial Find-In-File Directories

(setq top:*initial-search-directories* 'nil)

;; Initial Toolbar Icons

(setq top:*use-acl-toolbar* t) 
(setq top:*acl-toolbar-icons* 
   '(:find-toploop-prompt :gap :new :open :save :save-all :load :gap 
      :eval :eval-definition :eval-clipboard :build-call :macroexpand 
      :gap :browse-class :browse-generic-function :gap :inspect 
      :find-definition :find-in-file :gap :create-window :edit-window 
      :run-window :gap :trace :untrace :untrace-all :trace-status :gap 
      :breakpoint :unbreakpoint :unbreakpoint-all :breakpoint-status 
      :gap :print :gap :apropos :lambda-list :windows-help))

;; Window Positions and Sizes

(top:restore-window-region :lisp-frame-window 
   #.(make-box -4 -4 1028 744))
(top:restore-window-region :toploop-window #.(make-box -4 -4 1028 623))
(top:restore-window-region :help-output #.(make-box 22 24 766 289))
(top:restore-window-region :find-definition-dialog 
   #.(make-box 55 55 523 262))
(top:restore-window-region :history-browser-dialog 
   #.(make-box 70 27 606 321))

;; End of file
